function [xr,yr]=gSaveBinaryMatrix(fnam,x,y,M)
// SAVE_BINARY_MATRIX save x,y,M in the matrix binary format of Gnuplot
//   Usage: gSaveBinaryMatrix(fnam,x,y,M)
//
//   Input parameters:
//       fnam    - filename of the data file
//       x       - x axis values
//       y       - y axis values
//       M       - matrix data size(M)=y,x
//
//   SAVE_BINARY_MATRIX(file,x,y,M) saves the values of x,y and M in a binary
//   matrix format useable by Gnuplot, see
//   http://www.gnuplot.info/docs_4.4/gnuplot.html#x1-33700077.1.1 for details.
//

// AUTHOR: Hagen Wierstorf (matlab)
// AUTHOR: Klaus-Dieter Liss (scilab)

[ly,lx] = size(M);

if length(x) == 0 then
   x=1:lx;
   end
   
if length(y) == 0 then
   y=1:ly;
   end
   

y=matrix(y,1,length(y));
x=matrix(x,length(x),1);



// Create matrix to store in the file
MS = zeros(length(x)+1,length(y)+1);
MS(1,1) = length(x);
MS(1,2:$) = y;
MS(2:$,1) = x;
MS(2:$,2:$) = M';

// Write data into the file
fd = mopen(fnam,'wb');
mput(MS,'f',fd);
mclose(fd);

xr=x; yr=y;
endfunction

